@@ -5,9 +5,15 @@ from . import CodeGenHelper as cgh
     
 def makeSignalDescription(signals, json : bool):
     signalDescription = {}
-    signalDescription['names'] = cgh.signalListHelper_names(signals)
+    signalDescription['names'] = cgh.signal_list_to_name_list(signals)
     signalDescription['cpptypes'] = cgh.signalListHelper_typeNames(signals)
 
+    signalDescription['properties'] = []
+    signalDescription['port_numbers'] = []
+    for s in signals:
+        signalDescription['properties'].append( s.properties )
+        signalDescription['port_numbers'].append( s.port )
+
     if not json:
         # types will not be available when exported to JSON
         signalDescription['types'] = cgh.signalListHelper_types(signals)
@@ -15,9 +21,6 @@ def makeSignalDescription(signals, json : bool):
     return signalDescription
 
 
-
-
-
 class SystemManifest(object):
 
     def __init__(self, mainSimulation ):
