@@ -81,6 +81,18 @@ def leave_system():
 def clear():
     init_simulation_context()
 
-def set_primary_outputs(output_signals):
+def set_primary_outputs(output_signals, names = None):
+
+    if names is not None:
+        for i in range(0,len(names)):
+            output_signals[i].set_name_raw( names[i] )
+
     get_simulation_context().set_primary_outputs( si.unwrap_list( output_signals ) )
 
+def append_primay_ouput(output_signal, export_name : str = None):
+
+    if export_name is not None:
+        output_signal.set_name_raw(export_name)
+
+    get_simulation_context().append_primay_ouput(output_signal.unwrap)
+    
\ No newline at end of file
